@@ -31,11 +31,10 @@ from qiskit.circuit.library import YGate
 from qiskit.circuit.library import ZGate
 from qiskit.providers import BackendV2 as Backend
 from qiskit.providers import Options
-from qiskit.transpiler import InstructionProperties
 from qiskit.transpiler import Target
 
-from .qryd_gates import PCZGate
-from .qryd_job import QRydJob
+from qiskit_qryd_provider.pcz_gate import PCZGate
+from qiskit_qryd_provider.qryd_job import QRydJob
 
 if TYPE_CHECKING:
     import qiskit
@@ -686,81 +685,81 @@ class QRydEmuCloudcompSquare(QRydBackend):
         self._target = Target()
 
         # Add native gates
-        meas_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        meas_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(Measure(), meas_props)
 
         lam = Parameter("lambda")
-        p_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        p_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(PhaseGate(lam), p_props)
 
         theta = Parameter("theta")
         phi = Parameter("phi")
-        r_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        r_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RGate(theta, phi), r_props)
 
         theta = Parameter("theta")
-        rx_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        rx_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RXGate(theta), rx_props)
 
         theta = Parameter("theta")
-        ry_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        ry_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RYGate(theta), ry_props)
 
-        pcz_props = {tuple(edge): InstructionProperties() for edge in edges}
+        pcz_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(PCZGate(), pcz_props)
 
         # Add additional gates: single qubit gates
         # see https://github.com/Qiskit/qiskit-aer/blob/bb47adcf2e49b1e486e9ed15b3d55b6c4a345b1b/qiskit/providers/aer/backends/backend_utils.py#L52  # noqa: E501
 
-        h_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        h_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(HGate(), h_props)
 
         theta = Parameter("theta")
-        rz_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        rz_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RZGate(theta), rz_props)
 
         theta = Parameter("theta")
         phi = Parameter("phi")
         lam = Parameter("lambda")
-        u_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        u_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(UGate(theta, phi, lam), u_props)
 
-        x_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        x_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(XGate(), x_props)
 
-        y_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        y_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(YGate(), y_props)
 
-        z_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        z_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(ZGate(), z_props)
 
-        sx_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        sx_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(SXGate(), sx_props)
 
-        sxdg_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        sxdg_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(SXdgGate(), sxdg_props)
 
         # Add additional gates: controlled gates
 
-        cx_props = {tuple(edge): InstructionProperties() for edge in edges}
+        cx_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(CXGate(), cx_props)
 
-        cy_props = {tuple(edge): InstructionProperties() for edge in edges}
+        cy_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(CYGate(), cy_props)
 
-        cz_props = {tuple(edge): InstructionProperties() for edge in edges}
+        cz_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(CZGate(), cz_props)
 
         theta = Parameter("theta")
-        cp_props = {tuple(edge): InstructionProperties() for edge in edges}
+        cp_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(CPhaseGate(theta), cp_props)
 
         # Add additional gates: other two qubit unitaries
 
-        swap_props = {tuple(edge): InstructionProperties() for edge in edges}
+        swap_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(SwapGate(), swap_props)
 
-        iswap_props = {tuple(edge): InstructionProperties() for edge in edges}
+        iswap_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(iSwapGate(), iswap_props)
 
 
@@ -817,81 +816,81 @@ class QRydEmuCloudcompTriangle(QRydBackend):
         self._target = Target()
 
         # Add native gates
-        meas_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        meas_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(Measure(), meas_props)
 
         lam = Parameter("lambda")
-        p_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        p_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(PhaseGate(lam), p_props)
 
         theta = Parameter("theta")
         phi = Parameter("phi")
-        r_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        r_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RGate(theta, phi), r_props)
 
         theta = Parameter("theta")
-        rx_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        rx_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RXGate(theta), rx_props)
 
         theta = Parameter("theta")
-        ry_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        ry_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RYGate(theta), ry_props)
 
-        pcz_props = {tuple(edge): InstructionProperties() for edge in edges}
+        pcz_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(PCZGate(), pcz_props)
 
         # Add additional gates: single qubit gates
         # see https://github.com/Qiskit/qiskit-aer/blob/bb47adcf2e49b1e486e9ed15b3d55b6c4a345b1b/qiskit/providers/aer/backends/backend_utils.py#L52  # noqa: E501
 
-        h_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        h_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(HGate(), h_props)
 
         theta = Parameter("theta")
-        rz_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        rz_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RZGate(theta), rz_props)
 
         theta = Parameter("theta")
         phi = Parameter("phi")
         lam = Parameter("lambda")
-        u_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        u_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(UGate(theta, phi, lam), u_props)
 
-        x_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        x_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(XGate(), x_props)
 
-        y_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        y_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(YGate(), y_props)
 
-        z_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        z_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(ZGate(), z_props)
 
-        sx_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        sx_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(SXGate(), sx_props)
 
-        sxdg_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        sxdg_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(SXdgGate(), sxdg_props)
 
         # Add additional gates: controlled gates
 
-        cx_props = {tuple(edge): InstructionProperties() for edge in edges}
+        cx_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(CXGate(), cx_props)
 
-        cy_props = {tuple(edge): InstructionProperties() for edge in edges}
+        cy_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(CYGate(), cy_props)
 
-        cz_props = {tuple(edge): InstructionProperties() for edge in edges}
+        cz_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(CZGate(), cz_props)
 
         theta = Parameter("theta")
-        cp_props = {tuple(edge): InstructionProperties() for edge in edges}
+        cp_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(CPhaseGate(theta), cp_props)
 
         # Add additional gates: other two qubit unitaries
 
-        swap_props = {tuple(edge): InstructionProperties() for edge in edges}
+        swap_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(SwapGate(), swap_props)
 
-        iswap_props = {tuple(edge): InstructionProperties() for edge in edges}
+        iswap_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(iSwapGate(), iswap_props)
 
 
@@ -954,27 +953,27 @@ class QRydEmuLocalcompSquare(QRydBackend):
         self._target = Target()
 
         # Add native gates
-        meas_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        meas_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(Measure(), meas_props)
 
         lam = Parameter("lambda")
-        p_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        p_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(PhaseGate(lam), p_props)
 
         theta = Parameter("theta")
         phi = Parameter("phi")
-        r_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        r_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RGate(theta, phi), r_props)
 
         theta = Parameter("theta")
-        rx_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        rx_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RXGate(theta), rx_props)
 
         theta = Parameter("theta")
-        ry_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        ry_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RYGate(theta), ry_props)
 
-        pcz_props = {tuple(edge): InstructionProperties() for edge in edges}
+        pcz_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(PCZGate(), pcz_props)
 
 
@@ -1071,25 +1070,25 @@ class QRydEmuLocalcompTriangle(QRydBackend):
         self._target = Target()
 
         # Add native gates
-        meas_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        meas_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(Measure(), meas_props)
 
         lam = Parameter("lambda")
-        p_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        p_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(PhaseGate(lam), p_props)
 
         theta = Parameter("theta")
         phi = Parameter("phi")
-        r_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        r_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RGate(theta, phi), r_props)
 
         theta = Parameter("theta")
-        rx_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        rx_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RXGate(theta), rx_props)
 
         theta = Parameter("theta")
-        ry_props = {(qubit,): InstructionProperties() for qubit in range(num_qubits)}
+        ry_props = {(qubit,): None for qubit in range(num_qubits)}
         self._target.add_instruction(RYGate(theta), ry_props)
 
-        pcz_props = {tuple(edge): InstructionProperties() for edge in edges}
+        pcz_props = {tuple(edge): None for edge in edges}
         self._target.add_instruction(PCZGate(), pcz_props)
